@@ -1,4 +1,4 @@
-from moviepy.video.ImageClip import ColorClip
+from moviepy.video.VideoClip import ColorClip
 from moviepy.video.compositing.CompositeVideoClip import CompositeVideoClip
 
 def on_color(clip, size=None, color=(0, 0, 0), pos=None, col_opacity=None):
